@@ -1,7 +1,7 @@
 package main
 
 import (
-	"github.com/hashicorp/terraform-plugin-sdk/plugin"
+	"github.com/hashicorp/terraform/plugin"
 	"github.com/terraform-providers/terraform-provider-openstack/openstack"
 )
 
